/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.logging;

import java.util.logging.Level;
import java.util.logging.LogRecord;
import java.util.logging.Logger;
import org.apache.commons.lang.exception.ExceptionUtils;

/**
 *
 * @author Timon Veenstra
 */
public class AppLogger extends Logger{

    public AppLogger(String name,Class clazz) {
        super(name,findName(clazz));
        setLevel(Level.ALL);
    }

    /** Finds package name for given class */
    private static String findName(Class clazz) {
        String pref = clazz.getName();
        int last = pref.lastIndexOf('.');

        if (last >= 0) {
            pref = pref.substring(0, last + 1);

            return pref + "Bundle"; // NOI18N
        } else {
            // base package, search for bundle
            return "Bundle"; // NOI18N
        }
    }

    public void info(String msg, Object... objects) {
        LogRecord record = new LogRecord(Level.INFO, msg);
        record.setResourceBundle(getResourceBundle());
        record.setParameters(objects);
        super.log(record);
    }

    public void trace(Throwable t){
        log(Level.FINE,ExceptionUtils.getStackTrace(t));
    }

    public void error(String msg, Throwable throwable) {
        log(Level.SEVERE, msg, throwable);
    }

    public void error(String msg) {
        severe(msg);
    }

    public void error(String msg, Object... objects) {
        log(Level.SEVERE, msg, objects);
    }
    
    public void warning(String msg, Object... objects) {
        log(Level.WARNING, msg, objects);
    }
}
